| plot.Nests2 | R Documentation |
Show the plot of temperatures with set of nests
If time is "absolute", LayingTime must be indicated in FormatNests()
xlim being auto-month used the closest begin and end of month and
auto-year uses the clsest begin and end of year.
## S3 method for class 'Nests2'
plot(
x,
series = "all",
time = "relative",
show.heterogeneity = TRUE,
probs.heterogeneity = c(0.025, 0.5, 0.975),
col.heterogeneity = rgb(red = 0.2, green = 0.2, blue = 0.2, alpha = 0.6),
show.legend.names = TRUE,
show.legend.heterogeneity = TRUE,
control.legend.heterogeneity = list(),
control.legend.names = list(),
col = "black",
cex.axis = 1,
xlim = "auto",
xlab.axis = NULL,
...
)
x |
Data formated using formatdata. |
series |
Series to be used, logical (TRUE ou FALSE), numbers or names. If "all", all series are used. |
time |
Can be relative or absolute. |
show.heterogeneity |
If TRUE, show the 95% heterogeneity in grey. |
probs.heterogeneity |
Quantiles of heterogeneity. |
col.heterogeneity |
Color of heterogeneity. |
show.legend.names |
Show a legend for names. |
show.legend.heterogeneity |
Show the heterogeneity legend. |
control.legend.heterogeneity |
The list of parameters for legend of heterogeneity. |
control.legend.names |
The list of parameters for legend of names. |
col |
A recycled vector of colors. |
cex.axis |
The size of x-axis labels |
xlim |
The xlim parameter of plot or can be "auto", "auto-month", or "auto-year" |
xlab.axis |
Labels of x-axis |
... |
Parameters used by plot function |
plot.Nests2 shows the plot of temperatures for set of nests
The position of labels if xaxt="n" is used.
Marc Girondot marc.girondot@universite-paris-saclay.fr
## Not run:
library(embryogrowth)
data(nest)
formated <- FormatNests(nest)
plot(x=formated, series="all", col=rainbow(21))
plot(x=formated, series=1, main="DY.1")
Laying.Time <- matrix(c("DY.1", "15/05/2010",
"DY.17", "24/05/2010",
"DY.16", "24/05/2010",
"DY.18", "25/05/2010",
"DY.20", "25/05/2010",
"DY.21", "26/05/2010",
"DY.22", "26/05/2010",
"DY.23", "26/05/2010",
"DY.24", "27/05/2010",
"DY.25", "27/05/2010",
"DY.28", "28/05/2010",
"DY.26", "28/05/2010",
"DY.27", "28/05/2010",
"DY.146", "20/06/2010",
"DY.147", "20/06/2010",
"DY.172", "24/06/2010",
"DY.175", "24/06/2010",
"DY.170", "24/06/2010",
"DY.260", "06/07/2010",
"DY.282", "12/07/2010",
"DY.310", "18/07/2010",
"DY.309", "18/07/2010",
"DY.328", "25/07/2010",
"DY.331", "26/07/2010"), byrow=TRUE, ncol=2)
tz <- OlsonNames()[grepl("Asia/Istanbul", OlsonNames())]
Laying.Time_f <- as.POSIXlt.character(Laying.Time[, 2], format = "%d/%m/%Y", tz=tz)
names(Laying.Time_f) <- Laying.Time[, 1]
formated <- FormatNests(data=nest, previous=NULL, col.Time="Time", LayingTime=Laying.Time_f)
plot(x=formated, time="absolute", ylim=c(20, 35),
col= rainbow(21, alpha = 1), control.legend.heterogeneity=list(cex.0.5))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.